0,1,6-fach Taster Gira
16,17,Taster 1
16,18,Taster 2
16,19,Taster 3
16,20,Taster 4
16,21,Taster 5
16,22,Taster 6
21,49,Led 1
21,50,Led 2
21,51,Led 3
21,52,Led 4
21,53,Led 5
21,54,Led 6
20,16,Hintergrundbeleuchtung LEDs
21,70,Hintergrundbeleuchtung Beschriftung
16,33,Extern Taster 1
16,34,Extern Taster 2
16,35,Extern Taster 3
16,36,Extern Taster 4
21,65,Extern Led 1
21,66,Extern Led 2
21,67,Extern Led 3
21,68,Extern Led 4
34,1,Feuchtesensor
39,1,Helligkeitssensor
32,1,Temperatursensor
32,2,Temperatursensor
32,3,Temperatursensor
32,4,Temperatursensor
32,5,Temperatursensor
43,65,RFID Leser
43,67,RFID Leser
164,1,WiFi